" Execute the nnoremap lines anyway, otherwise the definition of '\lb'
" disappeared after loading a new file.
nnoremap <buffer> <Leader>ll :call CTeX_CTeX()<CR>
nnoremap <buffer> <Leader>lv :silent! call CTeX_ViewDVI()<CR>
nnoremap <buffer> <Leader>ls :silent! call CTeX_ForwardSearch()<CR>
nnoremap <buffer> <Leader>lb :call CTeX_QuickBuild()<CR>

if exists('s:did_installed_CTeX_Menu')
  finish
endif

let s:did_installed_CTeX_Menu = 1

" Delete some less useful ToolBar buttons to save space
aunmenu ToolBar.Print
aunmenu ToolBar.LoadSesn
aunmenu ToolBar.SaveSesn
aunmenu ToolBar.Help
aunmenu ToolBar.FindHelp
aunmenu ToolBar.Make
"aunmenu Tools.Make

"am ToolBar.Empty	:<CR>
an ToolBar.-SEP100-	<Nop>

tm icon=/usr/share/ite/bitmaps/CTeX.xpm ToolBar.CTeX LaTeX  --- \ll
am ToolBar.CTeX		:silent! call CTeX_CTeX()<CR>

" Note: LaTeX-Suite might change CWD when loading a new buffer via
" xdvik's reverse search. This function sets CWD to the directory of the
" main file.
fun <SID>CTeX_chdir()
    let maindir = fnamemodify(<SID>MainFile(), ':h')
    if maindir != ""
	exec 'cd '.maindir
    endif
endfun

" returns the basename (i.e., without extension) of the main file
fun <SID>MainBase()
    return fnamemodify(<SID>MainFile(), ':r')
endfun

" returns the name of the main file
fun <SID>MainFile()
    let mainfile = glob('*.latexmain')
    if mainfile == ''
	" no .latexmain file
	"return expand("#1")	"suppose buffer 1 the mainfile
	return expand("%")	"suppose current buffer
    else
	" strip trailing .latexmain
	return fnamemodify(mainfile, ':r')
    fi
endfun

tm icon=/usr/share/ite/bitmaps/XDvi.xpm ToolBar.XDvi DVI Ԥ --- \lv
an ToolBar.XDvi		:silent! call CTeX_ViewDVI()<CR>
fun CTeX_CTeX()
    wall
    call <SID>CTeX_chdir()
    cclose
    pclose!
    let curfile = expand("%")
    exec 'edit '.<SID>MainFile()
    let &makeprg = $VTEX_CTEXCMD.' '.$VTEX_OPTS.' -interaction=nonstopmode'
    " We use the .log file instead of stdout/stderr since ctex
    " might run latex for multiple times.

    "let &shellpipe = '; /usr/share/ite/logfilter '.<SID>MainBase().'.log > '
    "	\ .<SID>MainBase().'.log.tmp; /bin/mv -f '.<SID>MainBase().'.log.tmp '
    "	\ .<SID>MainBase().'.log; /bin/cat '.<SID>MainBase().'.log > '

    " filenames in the log file is handled by ctex-0.2.0
    let &shellpipe = '; /bin/cat '.<SID>MainBase().'.log > '

    exec 'make '.<SID>MainFile()

    if exists('g:Tex_IgnoredWarnings')
	call Tex_SetupErrorWindow()
    endif
    
    redraw!
    let winno = winnr()
    cwindow
    if winno != winnr()		" winnr() changed means at least one error
	cc!
    elseif curfile!=expand('%')	" no change in winnr() means no error
	exec 'edit '.curfile
    endif
endfun

fun CTeX_ViewDVI()
    call <SID>CTeX_chdir()
    let cmd = "env VTEX_CMD=\"kdvi-wrapper\" VTEX_XEDITOR=vtex XEDITOR=vtex "
    let cmd = cmd."VTEX_NAME=".$VTEX_NAME." vtex ".<SID>MainBase()." &"
    let dummy = system(cmd)
endfun

tm icon=/usr/share/ite/bitmaps/Search.xpm ToolBar.Search DVI  --- \ls
am ToolBar.Search	:silent! call CTeX_ForwardSearch()<CR>
fun CTeX_ForwardSearch()
    call <SID>CTeX_chdir()
    let cmd = "env VTEX_CMD=\"kdvi-wrapper\" VTEX_XEDITOR=vtex XEDITOR=vtex "
    let cmd = cmd."VTEX_NAME=".$VTEX_NAME." vtex \"file:"
    let cmd = cmd.<SID>MainBase()."#src:".line(".")
    let cmd = cmd." ".bufname("%")."\" &"
    let dummy = system(cmd)
endfun

tm icon=/usr/share/ite/bitmaps/Quick.xpm ToolBar.Quick +Ԥ --- \lb
am ToolBar.Quick	:call CTeX_QuickBuild()<CR>
fun CTeX_QuickBuild()
    call CTeX_CTeX()
    call CTeX_ViewDVI()
endfun

"am ToolBar.Empty1 :<CR>
an ToolBar.-sep101-	<Nop>

tm icon=/usr/share/ite/bitmaps/Spell.xpm ToolBar.Spell Ӣƴд
am ToolBar.Spell	:call CTeX_Spell()<CR>
fun CTeX_Spell()
    update
    so `/usr/share/ite/spell.sh %`
endfun

an ToolBar.-sep102-	<Nop>

tm icon=/usr/share/ite/bitmaps/Clean.xpm ToolBar.Clean ʱļ (ctextemp_*)
am ToolBar.Clean	:call CTeX_Clean()<CR>
fun CTeX_Clean()
    call <SID>CTeX_chdir()
    let dummy = strpart(input("ʱļ ctextemp_*.* (y/n) ? "), 0, 1)
    if dummy ==? "y"
	let dummy = system("sh -c 'ctex -clean 2>&1'")
    else
	let dummy = "cancelled!"
    endif
    echo dummy
endfun

" Note: LaTeX-Suite's compiler/tex.vim adds entries to efm according to
" the variable g:Tex_IgnoredWarnings whose custom definitions may be set here.
let g:Tex_IgnoreLevel = 0 
compiler tex

set tw=78 
set formatoptions+=tqmM
set encoding=euc-cn
"syntax sync minlines=100
"set lines=25
"set columns=80

if !exists('g:Tex_Folding')
  " without latexSuite, define '<<<,>>>' as foldmarker
  set foldmethod=marker
  set foldmarker=<<<,>>>
  syn match foldMarker	"%<<<"
  syn match foldMarker	"%>>>"
  highlight foldMarker guifg=darkred guibg=green
else
  " Add more folding items (TODO: how to insert these to latexSuite's
  " folding.vim ?
  "call AddSyntaxFoldItem('^\s*\\documentclass', '^\s*\\begin{document}', 0, -1)
  "call AddSyntaxFoldItem('^\s*\\begin{abstract}', '^\s*\\end{abstract}', 0, 0)
  "call AddSyntaxFoldItem('^\s*\\title{', '^\s*\\maketitle', 0, 0)
  "call MakeSyntaxFolds(1)
endif

if exists('g:Tex_MenuPrefix')
  let s:mainmenuname = g:Tex_MenuPrefix.'S&uite.'
  let s:mapleader = exists('mapleader') ? mapleader : "\\"

  " remove LaTeX-Suite menu items for compiling/viewing
  exec 'aunmenu '.s:mainmenuname.'Compile'
  exec 'aunmenu '.s:mainmenuname.'CompilePart'
  exec 'aunmenu '.s:mainmenuname.'View'
  exec 'aunmenu '.s:mainmenuname.'ViewPart'
  exec 'aunmenu '.s:mainmenuname.'Search'
  exec 'aunmenu '.s:mainmenuname.'Target\ Format'
  exec 'aunmenu '.s:mainmenuname.'Compiler\ Target'
  exec 'aunmenu '.s:mainmenuname.'Viewer\ Target'
  " exec 'aunmenu '.s:mainmenuname.'Set\ Ignore\ Level'
  exec 'aunmenu '.s:mainmenuname.'Complete\ Ref/Cite'
  exec 'aunmenu '.s:mainmenuname.'Project.Project'
  exec 'aunmenu '.s:mainmenuname.'Project.ProjectEdit'
  exec 'aunmenu '.s:mainmenuname.'Project.ProjectWrite'

  exec 'anoremenu 80.30 '.s:mainmenuname.'&Compile<tab>'.s:mapleader.'ll'.
	\'   :call CTeX_CTeX()<CR>'
  exec 'anoremenu 80.40 '.s:mainmenuname.'&View<tab>'.s:mapleader.'lv'.
	\'   :silent! call CTeX_ViewDVI()<CR>'
  exec 'anoremenu 80.50 '.s:mainmenuname.'&Search<tab>'.s:mapleader.'ls'.
	\'   :silent! call CTeX_ForwardSearch()<CR>'
  exec 'anoremenu 80.60 '.s:mainmenuname.'&Quick\ Build<tab>'.s:mapleader.'lb'.
	\'   :call CTeX_QuickBuild()<CR>'
endif
